package java.sql;

import java.net.URL;
import java.util.Calendar;
import java.util.Map;
import java.io.Reader;
import java.io.InputStream;
import java.math.BigDecimal;

public interface ResultSet extends Wrapper, AutoCloseable
{
    public static final int FETCH_FORWARD = 1000;
    public static final int FETCH_REVERSE = 1001;
    public static final int FETCH_UNKNOWN = 1002;
    public static final int TYPE_FORWARD_ONLY = 1003;
    public static final int TYPE_SCROLL_INSENSITIVE = 1004;
    public static final int TYPE_SCROLL_SENSITIVE = 1005;
    public static final int CONCUR_READ_ONLY = 1007;
    public static final int CONCUR_UPDATABLE = 1008;
    public static final int HOLD_CURSORS_OVER_COMMIT = 1;
    public static final int CLOSE_CURSORS_AT_COMMIT = 2;
    
    public abstract boolean next() throws SQLException;
    
    public abstract void close() throws SQLException;
    
    public abstract boolean wasNull() throws SQLException;
    
    public abstract String getString(int p0) throws SQLException;
    
    public abstract boolean getBoolean(int p0) throws SQLException;
    
    public abstract byte getByte(int p0) throws SQLException;
    
    public abstract short getShort(int p0) throws SQLException;
    
    public abstract int getInt(int p0) throws SQLException;
    
    public abstract long getLong(int p0) throws SQLException;
    
    public abstract float getFloat(int p0) throws SQLException;
    
    public abstract double getDouble(int p0) throws SQLException;
    
    @Deprecated
    public abstract BigDecimal getBigDecimal(int p0, int p1) throws SQLException;
    
    public abstract byte[] getBytes(int p0) throws SQLException;
    
    public abstract Date getDate(int p0) throws SQLException;
    
    public abstract Time getTime(int p0) throws SQLException;
    
    public abstract Timestamp getTimestamp(int p0) throws SQLException;
    
    public abstract InputStream getAsciiStream(int p0) throws SQLException;
    
    @Deprecated
    public abstract InputStream getUnicodeStream(int p0) throws SQLException;
    
    public abstract InputStream getBinaryStream(int p0) throws SQLException;
    
    public abstract String getString(String p0) throws SQLException;
    
    public abstract boolean getBoolean(String p0) throws SQLException;
    
    public abstract byte getByte(String p0) throws SQLException;
    
    public abstract short getShort(String p0) throws SQLException;
    
    public abstract int getInt(String p0) throws SQLException;
    
    public abstract long getLong(String p0) throws SQLException;
    
    public abstract float getFloat(String p0) throws SQLException;
    
    public abstract double getDouble(String p0) throws SQLException;
    
    @Deprecated
    public abstract BigDecimal getBigDecimal(String p0, int p1) throws SQLException;
    
    public abstract byte[] getBytes(String p0) throws SQLException;
    
    public abstract Date getDate(String p0) throws SQLException;
    
    public abstract Time getTime(String p0) throws SQLException;
    
    public abstract Timestamp getTimestamp(String p0) throws SQLException;
    
    public abstract InputStream getAsciiStream(String p0) throws SQLException;
    
    @Deprecated
    public abstract InputStream getUnicodeStream(String p0) throws SQLException;
    
    public abstract InputStream getBinaryStream(String p0) throws SQLException;
    
    public abstract SQLWarning getWarnings() throws SQLException;
    
    public abstract void clearWarnings() throws SQLException;
    
    public abstract String getCursorName() throws SQLException;
    
    public abstract ResultSetMetaData getMetaData() throws SQLException;
    
    public abstract Object getObject(int p0) throws SQLException;
    
    public abstract Object getObject(String p0) throws SQLException;
    
    public abstract int findColumn(String p0) throws SQLException;
    
    public abstract Reader getCharacterStream(int p0) throws SQLException;
    
    public abstract Reader getCharacterStream(String p0) throws SQLException;
    
    public abstract BigDecimal getBigDecimal(int p0) throws SQLException;
    
    public abstract BigDecimal getBigDecimal(String p0) throws SQLException;
    
    public abstract boolean isBeforeFirst() throws SQLException;
    
    public abstract boolean isAfterLast() throws SQLException;
    
    public abstract boolean isFirst() throws SQLException;
    
    public abstract boolean isLast() throws SQLException;
    
    public abstract void beforeFirst() throws SQLException;
    
    public abstract void afterLast() throws SQLException;
    
    public abstract boolean first() throws SQLException;
    
    public abstract boolean last() throws SQLException;
    
    public abstract int getRow() throws SQLException;
    
    public abstract boolean absolute(int p0) throws SQLException;
    
    public abstract boolean relative(int p0) throws SQLException;
    
    public abstract boolean previous() throws SQLException;
    
    public abstract void setFetchDirection(int p0) throws SQLException;
    
    public abstract int getFetchDirection() throws SQLException;
    
    public abstract void setFetchSize(int p0) throws SQLException;
    
    public abstract int getFetchSize() throws SQLException;
    
    public abstract int getType() throws SQLException;
    
    public abstract int getConcurrency() throws SQLException;
    
    public abstract boolean rowUpdated() throws SQLException;
    
    public abstract boolean rowInserted() throws SQLException;
    
    public abstract boolean rowDeleted() throws SQLException;
    
    public abstract void updateNull(int p0) throws SQLException;
    
    public abstract void updateBoolean(int p0, boolean p1) throws SQLException;
    
    public abstract void updateByte(int p0, byte p1) throws SQLException;
    
    public abstract void updateShort(int p0, short p1) throws SQLException;
    
    public abstract void updateInt(int p0, int p1) throws SQLException;
    
    public abstract void updateLong(int p0, long p1) throws SQLException;
    
    public abstract void updateFloat(int p0, float p1) throws SQLException;
    
    public abstract void updateDouble(int p0, double p1) throws SQLException;
    
    public abstract void updateBigDecimal(int p0, BigDecimal p1) throws SQLException;
    
    public abstract void updateString(int p0, String p1) throws SQLException;
    
    public abstract void updateBytes(int p0, byte[] p1) throws SQLException;
    
    public abstract void updateDate(int p0, Date p1) throws SQLException;
    
    public abstract void updateTime(int p0, Time p1) throws SQLException;
    
    public abstract void updateTimestamp(int p0, Timestamp p1) throws SQLException;
    
    public abstract void updateAsciiStream(int p0, InputStream p1, int p2) throws SQLException;
    
    public abstract void updateBinaryStream(int p0, InputStream p1, int p2) throws SQLException;
    
    public abstract void updateCharacterStream(int p0, Reader p1, int p2) throws SQLException;
    
    public abstract void updateObject(int p0, Object p1, int p2) throws SQLException;
    
    public abstract void updateObject(int p0, Object p1) throws SQLException;
    
    public abstract void updateNull(String p0) throws SQLException;
    
    public abstract void updateBoolean(String p0, boolean p1) throws SQLException;
    
    public abstract void updateByte(String p0, byte p1) throws SQLException;
    
    public abstract void updateShort(String p0, short p1) throws SQLException;
    
    public abstract void updateInt(String p0, int p1) throws SQLException;
    
    public abstract void updateLong(String p0, long p1) throws SQLException;
    
    public abstract void updateFloat(String p0, float p1) throws SQLException;
    
    public abstract void updateDouble(String p0, double p1) throws SQLException;
    
    public abstract void updateBigDecimal(String p0, BigDecimal p1) throws SQLException;
    
    public abstract void updateString(String p0, String p1) throws SQLException;
    
    public abstract void updateBytes(String p0, byte[] p1) throws SQLException;
    
    public abstract void updateDate(String p0, Date p1) throws SQLException;
    
    public abstract void updateTime(String p0, Time p1) throws SQLException;
    
    public abstract void updateTimestamp(String p0, Timestamp p1) throws SQLException;
    
    public abstract void updateAsciiStream(String p0, InputStream p1, int p2) throws SQLException;
    
    public abstract void updateBinaryStream(String p0, InputStream p1, int p2) throws SQLException;
    
    public abstract void updateCharacterStream(String p0, Reader p1, int p2) throws SQLException;
    
    public abstract void updateObject(String p0, Object p1, int p2) throws SQLException;
    
    public abstract void updateObject(String p0, Object p1) throws SQLException;
    
    public abstract void insertRow() throws SQLException;
    
    public abstract void updateRow() throws SQLException;
    
    public abstract void deleteRow() throws SQLException;
    
    public abstract void refreshRow() throws SQLException;
    
    public abstract void cancelRowUpdates() throws SQLException;
    
    public abstract void moveToInsertRow() throws SQLException;
    
    public abstract void moveToCurrentRow() throws SQLException;
    
    public abstract Statement getStatement() throws SQLException;
    
    public abstract Object getObject(int p0, Map<String, Class<?>> p1) throws SQLException;
    
    public abstract Ref getRef(int p0) throws SQLException;
    
    public abstract Blob getBlob(int p0) throws SQLException;
    
    public abstract Clob getClob(int p0) throws SQLException;
    
    public abstract Array getArray(int p0) throws SQLException;
    
    public abstract Object getObject(String p0, Map<String, Class<?>> p1) throws SQLException;
    
    public abstract Ref getRef(String p0) throws SQLException;
    
    public abstract Blob getBlob(String p0) throws SQLException;
    
    public abstract Clob getClob(String p0) throws SQLException;
    
    public abstract Array getArray(String p0) throws SQLException;
    
    public abstract Date getDate(int p0, Calendar p1) throws SQLException;
    
    public abstract Date getDate(String p0, Calendar p1) throws SQLException;
    
    public abstract Time getTime(int p0, Calendar p1) throws SQLException;
    
    public abstract Time getTime(String p0, Calendar p1) throws SQLException;
    
    public abstract Timestamp getTimestamp(int p0, Calendar p1) throws SQLException;
    
    public abstract Timestamp getTimestamp(String p0, Calendar p1) throws SQLException;
    
    public abstract URL getURL(int p0) throws SQLException;
    
    public abstract URL getURL(String p0) throws SQLException;
    
    public abstract void updateRef(int p0, Ref p1) throws SQLException;
    
    public abstract void updateRef(String p0, Ref p1) throws SQLException;
    
    public abstract void updateBlob(int p0, Blob p1) throws SQLException;
    
    public abstract void updateBlob(String p0, Blob p1) throws SQLException;
    
    public abstract void updateClob(int p0, Clob p1) throws SQLException;
    
    public abstract void updateClob(String p0, Clob p1) throws SQLException;
    
    public abstract void updateArray(int p0, Array p1) throws SQLException;
    
    public abstract void updateArray(String p0, Array p1) throws SQLException;
    
    public abstract RowId getRowId(int p0) throws SQLException;
    
    public abstract RowId getRowId(String p0) throws SQLException;
    
    public abstract void updateRowId(int p0, RowId p1) throws SQLException;
    
    public abstract void updateRowId(String p0, RowId p1) throws SQLException;
    
    public abstract int getHoldability() throws SQLException;
    
    public abstract boolean isClosed() throws SQLException;
    
    public abstract void updateNString(int p0, String p1) throws SQLException;
    
    public abstract void updateNString(String p0, String p1) throws SQLException;
    
    public abstract void updateNClob(int p0, NClob p1) throws SQLException;
    
    public abstract void updateNClob(String p0, NClob p1) throws SQLException;
    
    public abstract NClob getNClob(int p0) throws SQLException;
    
    public abstract NClob getNClob(String p0) throws SQLException;
    
    public abstract SQLXML getSQLXML(int p0) throws SQLException;
    
    public abstract SQLXML getSQLXML(String p0) throws SQLException;
    
    public abstract void updateSQLXML(int p0, SQLXML p1) throws SQLException;
    
    public abstract void updateSQLXML(String p0, SQLXML p1) throws SQLException;
    
    public abstract String getNString(int p0) throws SQLException;
    
    public abstract String getNString(String p0) throws SQLException;
    
    public abstract Reader getNCharacterStream(int p0) throws SQLException;
    
    public abstract Reader getNCharacterStream(String p0) throws SQLException;
    
    public abstract void updateNCharacterStream(int p0, Reader p1, long p2) throws SQLException;
    
    public abstract void updateNCharacterStream(String p0, Reader p1, long p2) throws SQLException;
    
    public abstract void updateAsciiStream(int p0, InputStream p1, long p2) throws SQLException;
    
    public abstract void updateBinaryStream(int p0, InputStream p1, long p2) throws SQLException;
    
    public abstract void updateCharacterStream(int p0, Reader p1, long p2) throws SQLException;
    
    public abstract void updateAsciiStream(String p0, InputStream p1, long p2) throws SQLException;
    
    public abstract void updateBinaryStream(String p0, InputStream p1, long p2) throws SQLException;
    
    public abstract void updateCharacterStream(String p0, Reader p1, long p2) throws SQLException;
    
    public abstract void updateBlob(int p0, InputStream p1, long p2) throws SQLException;
    
    public abstract void updateBlob(String p0, InputStream p1, long p2) throws SQLException;
    
    public abstract void updateClob(int p0, Reader p1, long p2) throws SQLException;
    
    public abstract void updateClob(String p0, Reader p1, long p2) throws SQLException;
    
    public abstract void updateNClob(int p0, Reader p1, long p2) throws SQLException;
    
    public abstract void updateNClob(String p0, Reader p1, long p2) throws SQLException;
    
    public abstract void updateNCharacterStream(int p0, Reader p1) throws SQLException;
    
    public abstract void updateNCharacterStream(String p0, Reader p1) throws SQLException;
    
    public abstract void updateAsciiStream(int p0, InputStream p1) throws SQLException;
    
    public abstract void updateBinaryStream(int p0, InputStream p1) throws SQLException;
    
    public abstract void updateCharacterStream(int p0, Reader p1) throws SQLException;
    
    public abstract void updateAsciiStream(String p0, InputStream p1) throws SQLException;
    
    public abstract void updateBinaryStream(String p0, InputStream p1) throws SQLException;
    
    public abstract void updateCharacterStream(String p0, Reader p1) throws SQLException;
    
    public abstract void updateBlob(int p0, InputStream p1) throws SQLException;
    
    public abstract void updateBlob(String p0, InputStream p1) throws SQLException;
    
    public abstract void updateClob(int p0, Reader p1) throws SQLException;
    
    public abstract void updateClob(String p0, Reader p1) throws SQLException;
    
    public abstract void updateNClob(int p0, Reader p1) throws SQLException;
    
    public abstract void updateNClob(String p0, Reader p1) throws SQLException;
    
    public abstract <T> T getObject(int p0, Class<T> p1) throws SQLException;
    
    public abstract <T> T getObject(String p0, Class<T> p1) throws SQLException;
    
    default public void updateObject(int n, Object o, SQLType sqlType, int n2) throws SQLException {
        throw new SQLFeatureNotSupportedException("updateObject not implemented");
    }
    
    default public void updateObject(String s, Object o, SQLType sqlType, int n) throws SQLException {
        throw new SQLFeatureNotSupportedException("updateObject not implemented");
    }
    
    default public void updateObject(int n, Object o, SQLType sqlType) throws SQLException {
        throw new SQLFeatureNotSupportedException("updateObject not implemented");
    }
    
    default public void updateObject(String s, Object o, SQLType sqlType) throws SQLException {
        throw new SQLFeatureNotSupportedException("updateObject not implemented");
    }
}
